@@ -82,7 +82,7 @@ class ShareBasicOpsBase(manager.ShareScenarioTest):
                                    error_on_invalid_ip_version=False):
         locations = None
         if share:
-            locations = self._get_share_export_locations(share)
+            locations = self.get_share_export_locations(share)
         elif snapshot:
             locations = self._get_snapshot_export_locations(snapshot)
 
@@ -93,17 +93,6 @@ class ShareBasicOpsBase(manager.ShareScenarioTest):
 
         return locations
 
-    def _get_share_export_locations(self, share):
-
-        if utils.is_microversion_lt(CONF.share.max_api_microversion, "2.9"):
-            locations = share['export_locations']
-        else:
-            exports = self.shares_v2_client.list_share_export_locations(
-                share['id'])
-            locations = [x['path'] for x in exports]
-
-        return locations
-
     def _get_snapshot_export_locations(self, snapshot):
         exports = (self.shares_v2_client.
                    list_snapshot_export_locations(snapshot['id']))
@@ -127,6 +116,11 @@ class ShareBasicOpsBase(manager.ShareScenarioTest):
     @tc.attr(base.TAG_NEGATIVE, base.TAG_BACKEND)
     def test_write_with_ro_access(self):
         '''Test if an instance with ro access can write on the share.'''
+        if self.protocol.upper() == 'CIFS':
+            msg = ("Skipped for CIFS protocol because RO access is not "
+                   "supported for shares by IP.")
+            raise self.skipException(msg)
+
         test_data = "Some test data to write"
 
         instance = self.boot_instance(wait_until="BUILD")
